"""Import terminal classes."""

from ansys.edb.core.terminal.terminals import (
    BoundaryType,
    BundleTerminal,
    Edge,
    EdgeTerminal,
    EdgeType,
    HfssPIType,
    PadEdge,
    PadstackInstanceTerminal,
    PinGroupTerminal,
    PointTerminal,
    PrimitiveEdge,
    SourceTermToGroundType,
    Terminal,
    TerminalInstance,
    TerminalInstanceTerminal,
    TerminalType,
)
