"""Import geometry classes."""

from ansys.edb.core.geometry.arc_data import ArcData
from ansys.edb.core.geometry.point3d_data import Point3DData
from ansys.edb.core.geometry.point_data import PointData
from ansys.edb.core.geometry.polygon_data import ExtentType, PolygonData, PolygonSenseType
from ansys.edb.core.geometry.r_tree import RTree
from ansys.edb.core.geometry.triangle3d_data import Triangle3DData
